@@ -1,11 +1,11 @@
-## version: 1.34
+## version: 1.28
 ## method: get
 ## path: /volumes/{name}
 ## code: 200
+## response: {"Name":"tardis","Driver":"custom","Mountpoint":"/var/lib/docker/volumes/tardis","Status":{"hello":"world"},"Labels":{"com.example.some-label":"some-value","com.example.some-other-label":"some-other-value"},"Scope":"local"}
 list(name = "tardis",
      driver = "custom",
      mountpoint = "/var/lib/docker/volumes/tardis",
-     created_at = "2016-06-07T20:31:11.853781916Z",
      status = list(hello = "world"),
      labels = c("com.example.some-label" = "some-value",
                 "com.example.some-other-label" = "some-other-value"),
