@@ -1,4 +1,4 @@
-## version: 1.38
+## version: 1.35
 ## method: get
 ## path: /secrets/{id}
 ## code: 200
@@ -15,5 +15,4 @@ list(
     driver = list(
       name = "secret-bucket",
       options = c(option_a = "value for driver option A",
-                  option_b = "value for driver option B")),
-    templating = NULL))
+                  option_b = "value for driver option B"))))
